@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+import copy
 import arrow
 from pprint import pprint
 from enum import Enum
@@ -81,7 +82,7 @@ class AdsV3ReportsAdapter(object):
         self.name = name
 
     def get_columns(self):
-        columns = self._base_metrics
+        columns = copy.deepcopy(self._base_metrics)
         for _gb in self.group_by:
             columns += self.GroupBy[_gb].columns
         columns += TimeUnit[self.time_unit].columns
